# phenopype: a phenotyping pipeline for python

phenopype is a high throughput phenotyping package for Python. It aims at supporting biologists in their efforts to extract high dimensional phenotypic data from digital images. phenopype provides high level functions for image processing that can be stacked and executed sequentially to efficiently process single images or large data sets. Users can interactively assemble their own function-stacks that can be customized and stored along with raw data for full reproducibility. 
